﻿/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2022
 */

import React from "react";
import { ImageBackground, Keyboard, StyleSheet, TouchableWithoutFeedback, View } from "react-native";

/**
 * Layout shared between all Unauthorized components (and the Profile screen)
 * @category Unauthorized
 * @component
 */
const UnauthorizedLayout : React.FC<{noPadding?: boolean}> = ({children, noPadding}) => {

    /**
     * Dismisses keyboard.
     */
    const dismissKeyboard = () => {
        Keyboard.dismiss();
    }

    return (
        <View style={{height: '100%', width: '100%'}} >
            <ImageBackground style={[!noPadding ? {padding: 25} : null, styles.background]} source={require('../../../assets/cover.jpg')}>
                <TouchableWithoutFeedback style={{height: '100%', width: '100%'}} onPress={dismissKeyboard}>
                    <View style={{height: '100%', width: '100%'}}>
                    {children}
                    </View>
                </TouchableWithoutFeedback>
            </ImageBackground>
        </View>
    )
}

const styles = StyleSheet.create({
    background: {
        flex: 1,
        resizeMode: 'cover',
    },
})

export default UnauthorizedLayout;